==> rn-adaptbyte-0.5.4.tgz: package/src/components/molecule/button/TextButton.tsx <==
import React from 'react';
import { StyleSheet, Pressable, type TextStyle } from 'react-native';
import { Typography } from '../../atom';
import type { TextButtonProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

const TextButton = ({
  title,
  size = 'default',
  underline,
  weight = 'bold',
  textColor,
  disabled,
  onPress,
  style,
  fontSize,
  ...props
}: TextButtonProps) => {
  const { styles, theme } = useStyles(stylesheet);

  const textStyle = StyleSheet.flatten([
    fontSize ? { fontSize } : styles[`text-size-${size}`],
    styles[`text-weight-${weight}`],
    underline && { textDecorationLine: 'underline' },
    {
      color: disabled
        ? theme.adaptbyte.colors.link.disabled
        : (textColor ?? theme.adaptbyte.colors.button.primary),
    },
  ]);

  return (
    <Pressable
      onPress={onPress}
      disabled={disabled}
      style={({ pressed }) => [
        styles.container,
        pressed && { opacity: 0.5 },
        style,
      ]}
      {...props}
    >
      <Typography.Paragraph style={textStyle as TextStyle} text={title} />
    </Pressable>
  );
};

export default TextButton;
const stylesheet = createStyleSheet((theme) => ({
  'container': {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
  },
  'text-weight-bold': {
    fontFamily: theme.adaptbyte.font.normal.bold,
  },
  'text-weight-medium': {
    fontFamily: theme.adaptbyte.font.normal.medium,
  },
  'text-size-small': {
    fontSize: theme.adaptbyte.typography.paragraph['text-02'].fontSize,
  },
  'text-size-default': {
    fontSize: theme.adaptbyte.typography.paragraph['text-03'].fontSize,
  },
}));

==> rn-adaptbyte-0.5.5.tgz: package/src/components/molecule/button/TextButton.tsx <==
import React from 'react';
import { StyleSheet, Pressable, type TextStyle } from 'react-native';
import { Typography } from '../../atom';
import type { TextButtonProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

const TextButton = ({
  title,
  size = 'default',
  underline,
  weight = 'bold',
  textColor,
  disabled,
  onPress,
  style,
  fontSize,
  textConfig,
  ...props
}: TextButtonProps) => {
  const { styles, theme } = useStyles(stylesheet);

  const textStyle = StyleSheet.flatten([
    fontSize ? { fontSize } : styles[`text-size-${size}`],
    styles[`text-weight-${weight}`],
    underline && { textDecorationLine: 'underline' },
    {
      color: disabled
        ? theme.adaptbyte.colors.link.disabled
        : (textColor ?? theme.adaptbyte.colors.button.primary),
    },
  ]);

  return (
    <Pressable
      onPress={onPress}
      disabled={disabled}
      style={({ pressed }) => [
        styles.container,
        pressed && { opacity: 0.5 },
        style,
      ]}
      {...props}
    >
      <Typography.Paragraph
        style={textStyle as TextStyle}
        text={title}
        {...textConfig}
      />
    </Pressable>
  );
};

export default TextButton;
const stylesheet = createStyleSheet((theme) => ({
  'container': {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
  },
  'text-weight-bold': {
    fontFamily: theme.adaptbyte.font.normal.bold,
  },
  'text-weight-medium': {
    fontFamily: theme.adaptbyte.font.normal.medium,
  },
  'text-size-small': {
    fontSize: theme.adaptbyte.typography.paragraph['text-02'].fontSize,
  },
  'text-size-default': {
    fontSize: theme.adaptbyte.typography.paragraph['text-03'].fontSize,
  },
}));
